@@ -103,7 +103,7 @@ typedef enum {
 	GS_APP_QUIRK_REMOVABLE_HARDWARE	= 1 << 10,	/* Since: 3.32 */
 	GS_APP_QUIRK_DEVELOPER_VERIFIED	= 1 << 11,	/* Since: 3.32 */
 	GS_APP_QUIRK_PARENTAL_FILTER	= 1 << 12,	/* Since: 3.32 */
-	GS_APP_QUIRK_NEW_PERMISSIONS    = 1 << 13,	/* Since: 3.32 */
+	GS_APP_QUIRK_NEW_PERMISSIONS	= 1 << 13,	/* Since: 3.32 */
 	GS_APP_QUIRK_PARENTAL_NOT_LAUNCHABLE	= 1 << 14,	/* Since: 3.32 */
 	/*< private >*/
 	GS_APP_QUIRK_LAST
@@ -132,8 +132,8 @@ typedef enum {
 } GsAppQuality;
 
 typedef enum {
-	GS_APP_PERMISSIONS_NONE 		= 0,
-	GS_APP_PERMISSIONS_UNKNOWN		= 1 << 0,
+	GS_APP_PERMISSIONS_UNKNOWN 		= 0,
+	GS_APP_PERMISSIONS_NONE			= 1 << 0,
 	GS_APP_PERMISSIONS_NETWORK 		= 1 << 1,
 	GS_APP_PERMISSIONS_SYSTEM_BUS   	= 1 << 2,
 	GS_APP_PERMISSIONS_SESSION_BUS		= 1 << 3,
