@@ -641,10 +641,8 @@ gs_appstream_refine_app (GsPlugin *plugin,
 			 GError **error)
 {
 	const gchar *tmp;
-	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GPtrArray) bundles = NULL;
 	g_autoptr(GPtrArray) launchables = NULL;
-	g_autoptr(GPtrArray) pkgnames = NULL;
 	g_autoptr(XbNode) req = NULL;
 
 	/* is compatible */
@@ -823,19 +821,6 @@ gs_appstream_refine_app (GsPlugin *plugin,
 	if (!gs_appstream_copy_metadata (app, component, error))
 		return FALSE;
 
-	/* add package names */
-	pkgnames = xb_node_query (component, "pkgname", 0, NULL);
-	if (pkgnames != NULL && gs_app_get_sources(app)->len == 0) {
-		for (guint i = 0; i < pkgnames->len; i++) {
-			XbNode *pkgname = g_ptr_array_index (pkgnames, i);
-			tmp = xb_node_get_text (pkgname);
-			if (tmp != NULL && tmp[0] != '\0')
-				gs_app_add_source (app, tmp);
-		}
-		gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_PACKAGE);
-		gs_app_set_scope (app, AS_APP_SCOPE_SYSTEM);
-	}
-
 	/* add bundles */
 	bundles = xb_node_query (component, "bundle", 0, NULL);
 	if (bundles != NULL && gs_app_get_sources(app)->len == 0) {
@@ -847,6 +832,22 @@ gs_appstream_refine_app (GsPlugin *plugin,
 		}
 	}
 
+	/* add legacy package names */
+	if (gs_app_get_bundle_kind (app) == AS_BUNDLE_KIND_UNKNOWN) {
+		g_autoptr(GPtrArray) pkgnames = NULL;
+		pkgnames = xb_node_query (component, "pkgname", 0, NULL);
+		if (pkgnames != NULL && gs_app_get_sources(app)->len == 0) {
+			for (guint i = 0; i < pkgnames->len; i++) {
+				XbNode *pkgname = g_ptr_array_index (pkgnames, i);
+				tmp = xb_node_get_text (pkgname);
+				if (tmp != NULL && tmp[0] != '\0')
+					gs_app_add_source (app, tmp);
+			}
+			gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_PACKAGE);
+			gs_app_set_scope (app, AS_APP_SCOPE_SYSTEM);
+		}
+	}
+
 	/* set origin for flatpaks */
 	if (gs_app_get_origin (app) == NULL &&
 	    gs_app_get_bundle_kind (app) == AS_BUNDLE_KIND_FLATPAK) {
@@ -1167,9 +1168,6 @@ gs_appstream_add_categories (GsPlugin *plugin,
 	for (guint j = 0; j < list->len; j++) {
 		GsCategory *parent = GS_CATEGORY (g_ptr_array_index (list, j));
 		GPtrArray *children = gs_category_get_children (parent);
-		g_autofree gchar *xpath = NULL;
-		g_autoptr(GError) error_local = NULL;
-		g_autoptr(GPtrArray) array = NULL;
 
 		for (guint i = 1; i < children->len; i++) { /* 1 to ignore all */
 			GsCategory *cat = g_ptr_array_index (children, i);
