@@ -2,25 +2,10 @@
  *
  * Copyright (C) 2017-2018 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0+
  */
 
-#ifndef __GS_FLATPAK_APP_H
-#define __GS_FLATPAK_APP_H
+#pragma once
 
 #include <gnome-software.h>
 #include <flatpak.h>
@@ -77,7 +62,3 @@ void			 gs_flatpak_app_set_main_app_ref_name	(GsApp		*app,
 const gchar		*gs_flatpak_app_get_main_app_ref_name	(GsApp		*app);
 
 G_END_DECLS
-
-#endif /* __GS_FLATPAK_APP_H */
-
-/* vim: set noexpandtab: */
