@@ -663,7 +663,6 @@ signout_activated_cb (GSimpleAction *action, GVariant *parameter, GsShell *shell
 {
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	const gchar *action_name, *auth_id;
-	g_autoptr(GsPluginJob) plugin_job = NULL;
 	GsAuth *auth;
 
 	action_name = g_action_get_name (G_ACTION (action));
@@ -979,6 +978,10 @@ gs_shell_show_event_refresh (GsShell *shell, GsPluginEvent *event)
 	g_autofree gchar *str_origin = NULL;
 	g_autoptr(GString) str = g_string_new (NULL);
 
+	/* ignore any errors from background downloads */
+	if (!gs_plugin_event_has_flag (event, GS_PLUGIN_EVENT_FLAG_INTERACTIVE))
+		return FALSE;
+
 	switch (error->code) {
 	case GS_PLUGIN_ERROR_DOWNLOAD_FAILED:
 		if (origin != NULL) {
@@ -1042,9 +1045,6 @@ gs_shell_show_event_refresh (GsShell *shell, GsPluginEvent *event)
 	case GS_PLUGIN_ERROR_CANCELLED:
 		break;
 	default:
-		/* non-interactive generic */
-		if (!gs_plugin_event_has_flag (event, GS_PLUGIN_EVENT_FLAG_INTERACTIVE))
-			return FALSE;
 		if (action == GS_PLUGIN_ACTION_DOWNLOAD) {
 			/* TRANSLATORS: failure text for the in-app notification */
 			g_string_append (str, _("Unable to download updates"));
@@ -1134,7 +1134,6 @@ gs_shell_show_event_install (GsShell *shell, GsPluginEvent *event)
 	GsShellEventButtons buttons = GS_SHELL_EVENT_BUTTON_NONE;
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	const GError *error = gs_plugin_event_get_error (event);
-	g_autofree gchar *msg = NULL;
 	g_autofree gchar *str_app = NULL;
 	g_autofree gchar *str_origin = NULL;
 	g_autoptr(GString) str = g_string_new (NULL);
@@ -1262,6 +1261,10 @@ gs_shell_show_event_update (GsShell *shell, GsPluginEvent *event)
 	g_autofree gchar *str_origin = NULL;
 	g_autoptr(GString) str = g_string_new (NULL);
 
+	/* ignore any errors from background downloads */
+	if (!gs_plugin_event_has_flag (event, GS_PLUGIN_EVENT_FLAG_INTERACTIVE))
+		return FALSE;
+
 	switch (error->code) {
 	case GS_PLUGIN_ERROR_DOWNLOAD_FAILED:
 		if (app != NULL && origin != NULL) {
